Class: Handlebars::Helpers::StringFormatting::Titleize
- Inherits:
-
BaseHelper
- Object
- BaseHelper
- Handlebars::Helpers::StringFormatting::Titleize
- Defined in:
- lib/handlebars/helpers/string_formatting/titleize.rb
Overview
titleize case the characters in the given ‘string’, aka heading case
Instance Method Summary collapse
-
#parse(value) ⇒ String
Parse will titleize case the characters in the given ‘string’, aka heading case.
Methods inherited from BaseHelper
#handlebars_helper, #parse_json, #struct_to_hash, #tokenizer, #wrapper
Instance Method Details
#parse(value) ⇒ String
Parse will titleize case the characters in the given ‘string’, aka heading case
28 29 30 31 32 33 34 35 |
# File 'lib/handlebars/helpers/string_formatting/titleize.rb', line 28 def parse(value) tokenizer.parse(value, separator: ' ', preserve_case: true, compress_prefix_numerals: false, compress_suffix_numerals: false) .titleize end |